@@ -1,4 +1,6 @@
-/* Copyright (c) 1992, Free Software Foundation, Inc.  All rights reserved.
+/* Copyright (c) 1994, Joseph Arceneaux.  All rights reserved.
+
+   Copyright (c) 1992, Free Software Foundation, Inc.  All rights reserved.
 
    Copyright (c) 1985 Sun Microsystems, Inc. Copyright (c) 1980 The Regents
    of the University of California. Copyright (c) 1976 Board of Trustees of
@@ -31,6 +33,7 @@ int else_endif_col;
 extern char *in_name;
 
 char *getenv ();
+void usage ();
 
 /* profile types */
 enum profile
@@ -41,7 +44,8 @@ enum profile
   PRO_IGN,			/* ignore it */
   PRO_KEY,			/* -T switch */
   PRO_SETTINGS,			/* bundled set of settings */
-  PRO_PRSTRING			/* Print string and exit */
+  PRO_PRSTRING,			/* Print string and exit */
+  PRO_FUNCTION			/* Call the associated function. */
 };
 
 /* profile specials for booleans */
@@ -126,7 +130,6 @@ int blanklines_after_procs;
 int use_stdout;
 int pointer_as_binop;
 int blanklines_after_declarations;
-int blanklines_before_blockcomments;
 int blanklines_around_conditional_compilation;
 int swallow_optional_blanklines;
 int n_real_blanklines;
@@ -134,6 +137,7 @@ int prefix_blankline_requested;
 int postfix_blankline_requested;
 int brace_indent;
 int btype_2;
+
 int space_sp_semicolon;
 int case_ind;
 int max_col;
@@ -152,7 +156,7 @@ int lineup_to_parens;
 int leave_preproc_space;
 int blank_after_sizeof;
 int blanklines_after_declarations_at_proctop;
-int block_comment_max_col;
+int comment_max_col;
 int extra_expression_indent;
 
 int expect_output_file;
@@ -174,7 +178,8 @@ struct pro
   /* if p_type == PRO_SETTINGS, a (char *) pointing to a list of the switches
      to set, separated by NULs, terminated by 2 NULs. if p_type == PRO_BOOL,
      PRO_INT, or PRO_FONT, address of the variable that gets set by the
-     option. if p_type == PRO_PRSTRING, a (char *) pointing to the string.  */
+     option. if p_type == PRO_PRSTRING, a (char *) pointing to the string.
+     if p_type == PRO_FUNCTION, a pointer to a function to be called. */
   int *p_obj;
 
   /* Points to a nonzero value (allocated statically for all options) if the
@@ -195,7 +200,6 @@ struct pro pro[] =
    &blanklines_after_declarations_at_proctop, &exp_badp},
   {"bad", PRO_BOOL, false, ON, &blanklines_after_declarations, &exp_bad},
   {"bap", PRO_BOOL, false, ON, &blanklines_after_procs, &exp_bap},
-  {"bbb", PRO_BOOL, false, ON, &blanklines_before_blockcomments, &exp_bbb},
   {"bc", PRO_BOOL, true, OFF, &leave_comma, &exp_bc},
   {"bli", PRO_INT, 0, ONOFF_NA, &brace_indent, &exp_bli},
   {"bl", PRO_BOOL, true, OFF, &btype_2, &exp_bl},
@@ -223,16 +227,17 @@ struct pro pro[] =
   {"fk", PRO_FONT, 0, ONOFF_NA, (int *) &keywordf, &exp_fk},
   {"fs", PRO_FONT, 0, ONOFF_NA, (int *) &stringf, &exp_fs},
   {"gnu", PRO_SETTINGS, 0, ONOFF_NA,
-   (int *) "-nbad\0-bap\0-nbbb\0-nbc\0-bl\0-ncdb\0-cs\0-nce\0-di2\0-ndj\0\
+   (int *) "-nbad\0-bap\0-nbc\0-bl\0-ncdb\0-cs\0-nce\0-di2\0-ndj\0\
 -ei\0-nfc1\0-i2\0-ip5\0-lp\0-pcs\0-nps\0-psl\0-nsc\0-nsob\0-bli2\0\
 -cp1\0-nfca\0", &exp_gnu},
+  {"h", PRO_FUNCTION, 0, 0, (int *) usage, &exp_version},
   {"ip", PRO_INT, 4, ON, &indent_parameters, &exp_ip},
   {"i", PRO_INT, 4, ONOFF_NA, &ind_size, &exp_i},
   {"kr", PRO_SETTINGS, 0, ONOFF_NA,
-   (int *) "-nbad\0-bap\0-nbbb\0-nbc\0-br\0-c33\0-cd33\0-ncdb\0-ce\0\
+   (int *) "-nbad\0-bap\0-nbc\0-br\0-c33\0-cd33\0-ncdb\0-ce\0\
 -ci4\0-cli0\0-d0\0-di1\0-nfc1\0-i4\0-ip0\0-l75\0-lp\0-npcs\0-npsl\0-cs\0\
 -nsc\0-nsc\0-nsob\0-nfca\0-cp33\0-nss\0", &exp_kr},
-  {"lc", PRO_INT, 0, ONOFF_NA, &block_comment_max_col, &exp_lc},
+  {"lc", PRO_INT, 0, ONOFF_NA, &comment_max_col, &exp_lc},
   {"lps", PRO_BOOL, false, ON, &leave_preproc_space, &exp_lps},
   {"lp", PRO_BOOL, true, ON, &lineup_to_parens, &exp_lp},
   {"l", PRO_INT, 78, ONOFF_NA, &max_col, &exp_l},
@@ -242,7 +247,6 @@ struct pro pro[] =
    &blanklines_after_declarations_at_proctop, &exp_badp},
   {"nbad", PRO_BOOL, false, OFF, &blanklines_after_declarations, &exp_bad},
   {"nbap", PRO_BOOL, false, OFF, &blanklines_after_procs, &exp_bap},
-  {"nbbb", PRO_BOOL, false, OFF, &blanklines_before_blockcomments, &exp_bbb},
   {"nbc", PRO_BOOL, true, ON, &leave_comma, &exp_bc},
   {"nbs", PRO_BOOL, false, OFF, &blank_after_sizeof, &exp_bs},
   {"ncdb", PRO_BOOL, true, OFF, &comment_delimiter_on_blankline, &exp_cdb},
@@ -295,7 +299,6 @@ struct pro pro[] =
    &blanklines_after_declarations_at_proctop, &exp_badp},
   {"bad", PRO_BOOL, false, ON, &blanklines_after_declarations, &exp_bad},
   {"bap", PRO_BOOL, true, ON, &blanklines_after_procs, &exp_bap},
-  {"bbb", PRO_BOOL, false, ON, &blanklines_before_blockcomments, &exp_bbb},
   {"bc", PRO_BOOL, true, OFF, &leave_comma, &exp_bc},
   {"bli", PRO_INT, 2, ONOFF_NA, &brace_indent, &exp_bli},
   {"bl", PRO_BOOL, true, OFF, &btype_2, &exp_bl},
@@ -325,17 +328,18 @@ struct pro pro[] =
 
 /* This is now the default. */
   {"gnu", PRO_SETTINGS, 0, ONOFF_NA,
-   (int *) "-nbad\0-bap\0-nbbb\0-nbc\0-bl\0-ncdb\0-cs\0-nce\0-di2\0-ndj\0\
+   (int *) "-nbad\0-bap\0-nbc\0-bl\0-ncdb\0-cs\0-nce\0-di2\0-ndj\0\
 -ei\0-nfc1\0-i2\0-ip5\0-lp\0-pcs\0-nps\0-psl\0-nsc\0-nsob\0-bli2\0\
 -cp1\0-nfca\0", &exp_gnu},
 
+  {"h", PRO_FUNCTION, 0, 0, (int *) usage, &exp_version},
   {"ip", PRO_INT, 5, ON, &indent_parameters, &exp_ip},
   {"i", PRO_INT, 2, ONOFF_NA, &ind_size, &exp_i},
   {"kr", PRO_SETTINGS, 0, ONOFF_NA,
-   (int *) "-nbad\0-bap\0-nbbb\0-nbc\0-br\0-c33\0-cd33\0-ncdb\0-ce\0\
+   (int *) "-nbad\0-bap\0-nbc\0-br\0-c33\0-cd33\0-ncdb\0-ce\0\
 -ci4\0-cli0\0-d0\0-di1\0-nfc1\0-i4\0-ip0\0-l75\0-lp\0-npcs\0-npsl\0-cs\0\
 -nsc\0-nsc\0-nsob\0-nfca\0-cp33\0-nss\0", &exp_kr},
-  {"lc", PRO_INT, 0, ONOFF_NA, &block_comment_max_col, &exp_lc},
+  {"lc", PRO_INT, 0, ONOFF_NA, &comment_max_col, &exp_lc},
   {"lps", PRO_BOOL, false, ON, &leave_preproc_space, &exp_lps},
   {"lp", PRO_BOOL, true, ON, &lineup_to_parens, &exp_lp},
   {"l", PRO_INT, 78, ONOFF_NA, &max_col, &exp_l},
@@ -345,7 +349,6 @@ struct pro pro[] =
    &blanklines_after_declarations_at_proctop, &exp_badp},
   {"nbad", PRO_BOOL, false, OFF, &blanklines_after_declarations, &exp_bad},
   {"nbap", PRO_BOOL, true, OFF, &blanklines_after_procs, &exp_bap},
-  {"nbbb", PRO_BOOL, false, OFF, &blanklines_before_blockcomments, &exp_bbb},
   {"nbc", PRO_BOOL, true, ON, &leave_comma, &exp_bc},
   {"nbs", PRO_BOOL, false, OFF, &blank_after_sizeof, &exp_bs},
   {"ncdb", PRO_BOOL, false, OFF, &comment_delimiter_on_blankline, &exp_cdb},
@@ -368,7 +371,7 @@ struct pro pro[] =
   {"nss", PRO_BOOL, false, OFF, &space_sp_semicolon, &exp_ss},
   {"nv", PRO_BOOL, false, OFF, &verbose, &exp_v},
   {"orig", PRO_SETTINGS, 0, ONOFF_NA,
-   (int *) "-nbap\0-nbad\0-nbbb\0-bc\0-br\0-c33\0-cd33\0-cdb\0-ce\0-ci4\0\
+   (int *) "-nbap\0-nbad\0-bc\0-br\0-c33\0-cd33\0-cdb\0-ce\0-ci4\0\
 -cli0\0-cp33\0-di16\0-fc1\0-fca\0-i4\0-ip4\0-l75\0-lp\0\
 -npcs\0-psl\0-sc\0-nsob\0-nss\0-ts8\0", &exp_orig},
 
@@ -433,13 +436,15 @@ struct long_option_conversion option_conversions[] =
   {"*", "fk"},
   {"*", "fs"},
   {"gnu-style", "gnu"},
+  {"help", "h"},
+  {"usage", "h"},
   {"parameter-indentation", "ip"},
   {"indentation-level", "i"},
   {"indent-level", "i"},
   {"k-and-r-style", "kr"},
   {"kernighan-and-ritchie-style", "kr"},
   {"kernighan-and-ritchie", "kr"},
-  {"*", "lc"},
+  {"comment-line-length", "lc"},
   {"continue-at-parentheses", "lp"},
   {"leave-preprocessor-space", "lps"},
   {"remove-preprocessor-space", "nlps"},
@@ -448,7 +453,6 @@ struct long_option_conversion option_conversions[] =
   {"no-blank-lines-after-procedure-declarations", "nbadp"},
   {"no-blank-lines-after-declarations", "nbad"},
   {"no-blank-lines-after-procedures", "nbap"},
-  {"no-blank-lines-after-block-comments", "nbbb"},
   {"no-blank-lines-after-commas", "nbc"},
   {"no-Bill-Shannon", "nbs"},
   {"no-blank-before-sizeof", "nbs"},
@@ -557,7 +561,9 @@ option_prefix (arg)
 /* Process an option ARG (e.g. "-l60").  PARAM is a possible value
    for ARG, if PARAM is nonzero.  EXPLICT should be nonzero iff the
    argument is being explicitly specified (as opposed to being taken from a
-   PRO_SETTINGS group of settings).  */
+   PRO_SETTINGS group of settings).
+
+   Returns 1 if the option had a value, returns 0 otherwise. */
 
 int
 set_option (option, param, explicit)
@@ -628,6 +634,10 @@ found:
 	  puts ((char *) p->p_obj);
 	  exit (0);
 
+	case PRO_FUNCTION:
+	  ((void(*)()) p->p_obj) ();
+	  break;
+
 	case PRO_SETTINGS:
 	  {
 	    char *t;		/* current position */
