@@ -1,4 +1,6 @@
-/* Copyright (c) 1992, Free Software Foundation, Inc.  All rights reserved.
+/* Copyright (c) 1994, Joseph Arceneaux.  All rights reserved.
+
+   Copyright (c) 1992, Free Software Foundation, Inc.  All rights reserved.
 
    Copyright (c) 1985 Sun Microsystems, Inc. Copyright (c) 1980 The Regents
    of the University of California. Copyright (c) 1976 Board of Trustees of
@@ -173,8 +175,8 @@ indent (this_file)
       writefdef (&stringf, 'S');
       writefdef (&keywordf, 'K');
     }
-  if (block_comment_max_col <= 0)
-    block_comment_max_col = max_col;
+  if (comment_max_col <= 0)
+    comment_max_col = max_col;
   if (decl_com_ind <= 0)	/* if not specified by user, set this */
     decl_com_ind =
       ljust_decl ? (com_ind <= 10 ? 2 : com_ind - 8) : com_ind;
@@ -207,7 +209,7 @@ indent (this_file)
 #if 0
     if (col > ind_size)
       parser_state_tos->ind_level = parser_state_tos->i_l_follow = col;
-#endif/
+#endif
   }
 
   if (troff)
@@ -269,8 +271,7 @@ indent (this_file)
 
 		save_com.ptr[0] = '{';
 
-	      else
-		{
+	      else		{
 		  /* Put it at the end, e.g. if (foo) / * comment here * / { */
 
 		  /* Putting in this newline causes a dump_line to occur
@@ -411,8 +412,9 @@ indent (this_file)
 	    {
 	      printf ("There were %d output lines and %d comments\n",
 		      (int) out_lines, (int) out_coms);
-	      printf ("(Lines with comments)/(Lines with code): %6.3f\n",
-		      (1.0 * com_lines) / code_lines);
+	      if (com_lines > 0 && code_lines > 0)
+		printf ("(Lines with comments)/(Lines with code): %6.3f\n",
+			(1.0 * com_lines) / code_lines);
 	    }
 	  fflush (output);
 	  if (found_err)
@@ -492,12 +494,13 @@ indent (this_file)
 	  break;
 
 	case newline:
-	  if ((parser_state_tos->last_token != comma
-	       || !leave_comma || !break_comma
-	       || parser_state_tos->p_l_follow > 0
-	       || parser_state_tos->block_init
-	       || s_com != e_com)
-	      && (parser_state_tos->last_token != rbrace || !btype_2)
+	  if (((parser_state_tos->last_token != comma
+		|| !leave_comma || !break_comma
+		|| parser_state_tos->p_l_follow > 0
+		|| parser_state_tos->block_init
+		|| s_com != e_com)
+	       && ((parser_state_tos->last_token != rbrace || !btype_2
+		    || ! parser_state_tos->in_decl)))
 	      || (compute_code_target () + (e_code - s_code)
 		  > max_col - tabsize))
 	    {
@@ -1335,18 +1338,13 @@ indent (this_file)
 		  *e_lab++ = *p++;
 
 		while (*buf_ptr == ' ' || *buf_ptr == TAB)
-		  {
-		    *e_lab++ = *buf_ptr++;
-		    if (buf_ptr >= buf_end)
-		      fill_buffer ();
-		  }
+		  *e_lab++ = *buf_ptr++;
 	      }
 	    else
 	      {
 		*e_lab++ = '#';
 		while (*buf_ptr == ' ' || *buf_ptr == TAB)
-		  if (++buf_ptr >= buf_end)
-		    fill_buffer ();
+		  buf_ptr++;
 	      }
 
 	    while (*buf_ptr != EOL || (in_comment && !had_eof))
@@ -1435,7 +1433,6 @@ indent (this_file)
 					   lexi will take tokens out of
 					   save_com */
 		need_chars (save_com, 1);
-		*save_com.end++ = ' ';	/* add trailing blank, just in case */
 		buf_end = save_com.end;
 		save_com.end = save_com.ptr;	/* make save_com empty */
 	      }
@@ -1619,9 +1616,12 @@ char *set_profile ();
 void set_defaults ();
 int set_option ();
 
-/* Points to current input file */
+/* Points to current input file name */
 char *in_name = 0;
 
+/* Points to the current input buffer */
+struct file_buffer *current_input = 0;
+
 /* Points to the name of the output file */
 char *out_name = 0;
 
@@ -1644,7 +1644,6 @@ main (argc, argv)
      char **argv;
 {
   register int i;
-  struct file_buffer *current_input;
   char *profile_pathname = 0;
   int using_stdin = false;
 
