@@ -1,5 +1,6 @@
+/* Copyright (c) 1994, Joseph Arceneaux.  All rights reserved
 
-/* Copyright (c) 1992, Free Software Foundation, Inc.  All rights reserved.
+   Copyright (c) 1992, Free Software Foundation, Inc.  All rights reserved.
 
    Copyright (c) 1985 Sun Microsystems, Inc. Copyright (c) 1980 The Regents
    of the University of California. Copyright (c) 1976 Board of Trustees of
@@ -131,7 +132,6 @@ extern char *be_save;		/* similarly saved value of buf_end */
 extern int use_stdout;
 extern int pointer_as_binop;
 extern int blanklines_after_declarations;
-extern int blanklines_before_blockcomments;
 extern int blanklines_after_procs;
 extern int blanklines_around_conditional_compilation;
 extern int swallow_optional_blanklines;
@@ -155,8 +155,9 @@ extern int *di_stack;
    (bype_2 == 0) code */
 extern int brace_indent;
 
-extern int btype_2;		/* when true, brace should be on same line as
-				   if, while, etc */
+/* when true, brace should be on same line as if, while, etc */
+extern int btype_2;
+
 /* If true, a space is inserted between if, while, or for, and a semicolon
    for example while (*p++ == ' ') ; */
 extern int space_sp_semicolon;
@@ -231,7 +232,7 @@ extern int blanklines_after_declarations_at_proctop;	/* This is vaguely
 							   to be generated even
 							   if there are no
 							   declarations */
-extern int block_comment_max_col;
+extern int comment_max_col;
 extern int extra_expression_indent;	/* True if continuation lines from
 					   the expression part of "if(e)",
 					   "while(e)", "for(e;e;e)" should be
