@@ -1,4 +1,6 @@
-/* Copyright (c) 1992, Free Software Foundation, Inc.  All rights reserved.
+/* Copyright (c) 1994, Joseph Arceneaux.  All rights reserved.
+
+   Copyright (c) 1992, Free Software Foundation, Inc.  All rights reserved.
 
    Copyright (c) 1985 Sun Microsystems, Inc. Copyright (c) 1980 The Regents
    of the University of California. Copyright (c) 1976 Board of Trustees of
@@ -57,37 +59,34 @@ int suppress_blanklines = 0;
 static int comment_open;
 
 int paren_target;
-
+
 /* Use `perror' to print the system error message
-   caused by OFFENDER. */
-
-static char *errbuf;
+   caused by OFFENDER, then exit. */
 
 void
 sys_error (offender)
      char *offender;
 {
-  int size = strlen (offender);
-  static int buffer_size;
+  int buffer_size;
+  char *errbuf;
+
+  /* Grab extra space to handle random unix lossage */
+  errbuf = (char *) xmalloc (strlen (offender) + 10);
 
-  if (errbuf == 0)
-    {
-      buffer_size = size + 10;	/* Extra for random unix lossage */
-      errbuf = (char *) xmalloc (buffer_size);
-    }
-  else if (size + 10 > buffer_size)
-    {
-      buffer_size = size + 10;
-      errbuf = xrealloc (errbuf, buffer_size);
-    }
   sprintf (errbuf, "indent: %s", offender);
   perror (errbuf);
   exit (1);
 }
 
 #ifdef VMS
+/* Folks say VMS requires its own read routine.  Then again, some folks
+   say it doesn't.  Different folks have also sent me conflicting versions
+   of this function.  Who's right?
+
+   Anyway, this version was sent by MEHRDAD@glum.dev.cf.ac.uk */
+
 int
-vms_read (int file_desc, void *buffer, int nbytes)
+vms_read (int file_desc, char *buffer, int nbytes)
 {
     register char *bufp;
     register int nread, nleft;
@@ -96,15 +95,17 @@ vms_read (int file_desc, void *buffer, int nbytes)
     nread = 0;
     nleft = nbytes;
 
-    while (nread = read (file_desc, bufp, nleft), nread > 0)
+    nread = read (file_desc, bufp, nleft);
+    while (nread > 0)
       {
         bufp += nread;
         nleft -= nread;
         if (nleft < 0)
-            sys_error ("Internal buffering error");
-    }
+	  sys_error ("Internal buffering error");
+	nread = read (file_desc, bufp, nleft);
+      }
 
-    return nread;
+    return nbytes - nleft;
 }
 #endif /* VMS */
 
@@ -150,7 +151,8 @@ current_column ()
     p = cur_line;
 
 #if 0
-  /* Paranoia */
+  /* Paranoia -- Turning this on breaks stuff, but I haven't yet
+     investigated. */
   if (! (buf_ptr >= cur_line && buf_ptr < in_prog_pos))
     abort ();
 #endif
@@ -165,9 +167,6 @@ current_column ()
 	break;
       case TAB:
 	column += tabsize - (column - 1) % tabsize;
-#if 0
-	column += tabsize - (column % tabsize) + 1;
-#endif
 	break;
       case '\b':		/* backspace */
 	column--;
@@ -331,27 +330,7 @@ dump_line ()
 
 	  cur_col = pad_output (cur_col, target_col);
 	  for (p = s_code; p < e_code; p++)
-	    {
-#if 0
-	      if (*p == (char) 0200)
-		fprintf (output, "%d", (int) (target_col * 7));
-	      else
-		if (tabsize > 1)
-#endif
-		putc (*p, output);
-
-#if 0
-	      else
-		{
-		  int width = 1;
-		  if (*p == TAB)
-		    width = (tabsize - ((cur_col - 1) % tabsize));
-		  cur_col += width;
-		  while (width--)
-		    putc (*p, output);
-		}
-#endif
-	    }
+	    putc (*p, output);
 	  cur_col = count_columns (cur_col, s_code);
 	}
 
@@ -558,10 +537,14 @@ read_file (filename)
   if (fstat (fd, &file_stats) < 0)
     sys_error (filename);
 
-  if (fileptr.data != 0)
-    free (fileptr.data);
+  if (file_stats.st_size <= 0)
+    diag (1, "Warning: Zero-length file %s", filename);
+
   fileptr.size = file_stats.st_size;
-  fileptr.data = (char *) xmalloc (file_stats.st_size + 1);
+  if (fileptr.data != 0)
+    fileptr.data = (char *) xrealloc (fileptr.data, file_stats.st_size + 1);
+  else
+    fileptr.data = (char *) xmalloc (file_stats.st_size + 1);
 
   size = SYS_READ (fd, fileptr.data, fileptr.size);
   if (size < 0)
@@ -572,10 +555,13 @@ read_file (filename)
   /* Apparently, the DOS stores files using CR-LF for newlines, but
      then the DOS `read' changes them into '\n'.  Thus, the size of the
      file on disc is larger than what is read into memory.  Thanks, Bill. */
-  if (size != fileptr.size)
+  if (size < fileptr.size)
     fileptr.size = size;
 
-  fileptr.name = (char *) xmalloc (namelen + 1);
+  if (fileptr.name != 0)
+    fileptr.name = (char *) xrealloc (fileptr.name, namelen + 1);
+  else
+    fileptr.name = (char *) xmalloc (namelen + 1);
   memcpy (fileptr.name, filename, namelen);
   fileptr.name[namelen] = '\0';
 
@@ -635,6 +621,9 @@ read_stdin ()
   return &stdinptr;
 }
 
+/* Points to the current input buffer */
+extern struct file_buffer *current_input;
+
 /* Advance `buf_ptr' so that it points to the next line of input.
 
    If the next input line contains an indent control comment turning
@@ -653,7 +642,7 @@ INLINE void
 fill_buffer ()
 {
   register char *p;
-  int inhibit_formatting = 0;
+  int finished_a_line;
 
   /* indent() may be saving the text between "if (...)" and the following
      statement.  To do so, it uses another buffer (`save_com').  Switch
@@ -669,21 +658,18 @@ fill_buffer ()
 	return;
     }
 
-  /* If formatting gets turned off, then just loop here outputting lines
-     until formatting is re-enabled. */
+  if (*in_prog_pos == '\0')
+    {
+      cur_line = buf_ptr = in_prog_pos;
+      had_eof = true;
+      return;
+    }
+
+  /* Here if we know there are chars to read. */
+  p = cur_line = in_prog_pos;
+  finished_a_line = 0;
   do
     {
-      /* Advance buf_ptr past last line, and return if EOF. */
-      cur_line = buf_ptr = in_prog_pos;
-      if (*buf_ptr == '\0')
-	{
-	  had_eof = true;
-	  return;
-	}
-
-      /* Examine the beginning of the line for an indent control
-         comment. */
-      p = buf_ptr;
       while (*p == ' ' || *p == TAB)
 	p++;
       if (*p == '/' && (*(p + 1) == '*' || *(p + 1) == '/'))
@@ -691,50 +677,98 @@ fill_buffer ()
 	  p += 2;
 	  while (*p == ' ' || *p == TAB)
 	    p++;
-	  if (! inhibit_formatting)
+	  if (! strncmp (p, "*INDENT-OFF*", 12))
 	    {
-	      if (! strncmp (p, "*INDENT-OFF*", 12))
+	      char *q = cur_line;
+	      int inhibited = 1;
+
+	      if (s_com != e_com || s_lab != e_lab || s_code != e_code)
+		dump_line ();
+	      while (q < p)
+		putc (*q++, output);
+	      do
 		{
-		  if (s_com != e_com || s_lab != e_lab || s_code != e_code)
-		    dump_line ();
-		  inhibit_formatting = 1;
-		}
-	    }
-	  else
-	    {
-	      if (! strncmp (p, "*INDENT-ON*", 11))
-		{
-		  p += 11;
-		  /* Set inhibit_formatting to 2 so that we will
-		     still toss out this whole line, but drop out
-		     of the loop afterwards. */
-		  inhibit_formatting = 2;
-		  n_real_blanklines = 0;
-		  postfix_blankline_requested = 0;
-		  prefix_blankline_requested = 0;
-		  suppress_blanklines = 1;
+		  while (*p != '\0' && *p != EOL)
+		    putc (*p++, output);
+		  if (*p == '\0'
+		      && (p - current_input->data) == current_input->size)
+		    {
+		      buf_ptr = buf_end = in_prog_pos = p;
+		      had_eof = 1;
+		      return;
+		    }
+
+		  if (*p == EOL)
+		    cur_line = p + 1;
+		  putc (*p++, output);
+		  while (*p == ' ' || *p == TAB)
+		    putc (*p++, output);
+		  if (*p == '/' && (*(p + 1) == '*' || *(p + 1) == '/'))
+		    {
+		      /* We've hit a comment.  See if turns formatting
+			 back on. */
+		      putc (*p++, output);
+		      putc (*p++, output);
+		      while (*p == ' ' || *p == TAB)
+			putc (*p++, output);
+		      if (! strncmp (p, "*INDENT-ON*", 11))
+			{
+			  do
+			    {
+			      while (*p != '\0' && *p != EOL)
+				putc (*p++, output);
+			      if (*p == '\0' && ((p - current_input->data)
+						 == current_input->size))
+				{
+				  buf_ptr = buf_end = in_prog_pos = p;
+				  had_eof = 1;
+				  return;
+				}
+			      else
+				{
+				  if (*p == EOL)
+				    {
+				      inhibited = 0;
+				      cur_line = p + 1;
+				    }
+				  putc (*p++, output);
+				}
+			    }
+			  while (inhibited);
+			}
+		    }
 		}
+	      while (inhibited);
 	    }
 	}
 
-      /* Now procede through the rest of the line */
       while (*p != '\0' && *p != EOL)
 	p++;
-      buf_end = in_prog_pos = p + 1;
 
-      if (inhibit_formatting)
+      /* Here for newline -- return unless formatting is off. */
+      if (*p == EOL)
 	{
-	  p = buf_ptr;
-	  while (p < buf_end)
-	    putc (*p++, output);
-	  if (inhibit_formatting == 2)
-	    {
-	      inhibit_formatting = 0;
-	      continue;
-	    }
+	  finished_a_line = 1;
+	  in_prog_pos = p + 1;
+	}
+      /* Here for embedded NULLs */
+      else if ((p - current_input->data) < current_input->size)
+	{
+	  diag (0, "Warning: File %s contains NULL-characters\n",
+		current_input->name);
+	  p++;
+	}
+      /* Here for EOF with no terminating newline char. */
+      else
+	{
+	  in_prog_pos = p;
+	  finished_a_line = 1;
 	}
     }
-  while (inhibit_formatting);
+  while (!finished_a_line);
+
+  buf_ptr = cur_line;
+  buf_end = in_prog_pos;
 }
 
 /* Fill the output line with whitespace up to TARGET_COLUMN, given that
