@@ -1,11 +1,15 @@
-/* Copyright (C) 1992 Free Software Foundation, Inc.
+/* Copyright (c) 1993,1994, Joseph Arceneaux.  All rights reserved.
 
-   This program is free software; you can redistribute it and/or modify
-   it without restriction.
+   This file is subject to the terms of the GNU General Public License as
+   published by the Free Software Foundation.  A copy of this license is
+   included with this software distribution in the file COPYING.  If you
+   do not have a copy, you may obtain a copy by writing to the Free
+   Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
-   This program is distributed in the hope that it will be useful,
+   This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  */
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details. */
 
 #include <stdio.h>
 
@@ -38,9 +42,11 @@ extern int debug;
 #endif /* VMS */
 
 #ifdef __MSDOS__
-#define ONE_DOT_PER_FILENAME 1
-#define USG   1
-#define NODIR 1
+# define ONE_DOT_PER_FILENAME 1
+# ifndef __GNUC__
+# define USG   1
+# endif
+# define NODIR 1
 #endif /* __MSDOS__ */
 
 /* configure defines USG if it can't find bcopy */
